@@ -45,7 +45,7 @@ CEcaIAManager::CEcaIAManager()
 {
   nTimerIDFinished = 0;
   nMasterPosition = 0;
-  bPlaying = false;
+  rStatus = NotRunning;
   //! \todo 󥻥åȥå "TEMP" ơ
   //! (ÿ֤)νԤ
 }
@@ -71,18 +71,10 @@ CEcaIAManager::isExisting(const QString& strTrackName) const
 
 /////////////////////////////////////////////////////////////////////////////
 
-bool
-CEcaIAManager::isPlaying()
+CEcaIAManager::RunningStatus
+CEcaIAManager::runningStatus() const
 {
-  if ( bPlaying ) {
-    return true;
-  }
-
-  if ( engineStatus() == CEcaIAManager::Running ) {
-    return true;
-  } else {
-    return false;
-  }
+  return rStatus;
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -157,6 +149,8 @@ CEcaIAManager::slotPlay(bool bRecord)
   case Finished:
     slotSetMasterPosition(0);
     break;
+  case Running:
+    return;
   default:
     break;
   }
@@ -172,7 +166,11 @@ CEcaIAManager::slotPlay(bool bRecord)
   killTimers(); // kill all timers
   nTimerIDFinished = startTimer(500); // 500-milisecond timer
 
-  bPlaying = true;
+  if ( bRecord ) {
+    rStatus = Recording;
+  } else {
+    rStatus = Playing;
+  }
 
   command("cs-connect");
   command("start");
@@ -187,9 +185,7 @@ CEcaIAManager::slotStop()
   command("cs-disconnect");
   slotSetMasterPosition(this->nMasterPosition);
   // need to reconnect? !!!!!!!!!!!!!!!!!!!!!!!!!!!!
-  removeTmpFiles();
-  bPlaying = false;
-  emit finished();
+  doDetailStopped();
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -239,9 +235,9 @@ CEcaIAManager::slotSetMasterPosition(int nSec)
 void
 CEcaIAManager::slotRewind(int nSecond)
 {
-  if ( isPlaying() ) {
+  if ( rStatus == Playing ) {
     command("cs-rewind " + QString("%1").arg(nSecond));
-  } else {
+  } else if ( rStatus == NotRunning ) {
     this->nMasterPosition -= nSecond;
     if ( nMasterPosition < 0 ) {
       this->nMasterPosition = 0;
@@ -258,9 +254,9 @@ CEcaIAManager::slotRewind(int nSecond)
 void
 CEcaIAManager::slotForward(int nSecond)
 {
-  if ( isPlaying() ) {
+  if ( rStatus == Playing ) {
     command("cs-forward " + QString("%1").arg(nSecond));
-  } else {
+  } else if ( rStatus == NotRunning) {
     this->nMasterPosition += nSecond;
     int nHour   = this->nMasterPosition / 3600;
     emit masterPositionChanged(QTime(nHour,
@@ -271,6 +267,87 @@ CEcaIAManager::slotForward(int nSecond)
 
 /////////////////////////////////////////////////////////////////////////////
 
+void
+CEcaIAManager::slotMixdown(
+  bool bWithPlaying, 
+  const QString& strChainsetup, 
+  const QString& strFileName)
+{
+  switch ( engineStatus() ) {
+  case NotReady:
+  case Error:
+    emit finished();
+    return;
+  case Finished:
+    slotSetMasterPosition(0);
+    break;
+  case Running:
+    return;
+  default:
+    break;
+  }
+
+  command("cs-add " + strChainsetup);
+  command("cs-select " + strChainsetup);
+
+  QValueVector<CTrackInf>::iterator it = vTrackChains.begin();
+  while ( it != vTrackChains.end() ) {
+    QFileInfo FileInfo((*it).strFileName);
+    if ( (*it).strFileName == "" ) {
+      continue;
+    } else if ( !FileInfo.exists() ) {
+      continue;
+    } else if ( !CVoxStormGlobal::isSupportedFileType((*it).strFileName) ) {
+      continue;
+    }
+
+    // create chain
+    QString strCommand = "c-add " + (*it).strTrackName;
+    command(strCommand);
+    
+    // select chain
+    slotSelectChain((*it).strTrackName);
+
+    // setup mute condition !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+    // if already this name track is existing...???
+    if ( (*it).bMute ) {
+      slotToggleMute((*it).strTrackName, (*it).bMute);
+    }
+
+    // NOTE : don't change order after parameter (level, pan, ...)
+    // CEcaIAManager object processes implicitly this order
+    // setup level
+    strCommand = "cop-add -ea:" + QString("%1").arg((*it).nLevel);
+    command(strCommand);
+    slotChangeLevel((*it).strTrackName, (*it).nLevel);
+
+    // setup pan
+    strCommand = "cop-add -epp:" + QString("%1").arg((*it).nPan);
+    command(strCommand);
+    slotChangePan((*it).strTrackName, (*it).nPan);
+
+    it++;
+  }
+
+  setMixdownIOToCurrentChainsetup(bWithPlaying, strFileName);
+  slotSetMasterPosition(this->nMasterPosition);
+
+  if ( !this->isValidChainsetup() ) {
+    emit finished();
+    return;
+  }
+
+  killTimers(); // kill all timers
+  nTimerIDFinished = startTimer(500); // 500-milisecond timer
+
+  rStatus = Mixing;
+
+  command("cs-connect");
+  command("start");
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 void
 CEcaIAManager::slotAddChain(const CTrackInf& TrackInfAdd)
 {
@@ -619,7 +696,6 @@ CEcaIAManager::command(const QString& strCommand, bool bOut)
 {
   EcaControler.command(strCommand.ascii());
   if ( bOut ) {
-    printf("  %s\n", strCommand.ascii());
     emit messageGenerated(strCommand + "\n");
   }
 }
@@ -787,6 +863,113 @@ CEcaIAManager::setIOToCurrentChainsetup(bool bRecord)
 
 /////////////////////////////////////////////////////////////////////////////
 
+void 
+CEcaIAManager::setMixdownIOToCurrentChainsetup(
+  bool bWithPlaying, 
+  const QString& strFileName)
+{
+  prepareTracks();
+
+  int nChains, i;
+  nChains = vPrepareTrackChains.size();
+
+  QString      strCommand;
+  QStringList  strlOutputDevices;
+  QStringList  strlInputFiles;
+  int          nResult;
+
+  // setup I/O
+  for ( i = 0; i < nChains; i++ ) {
+    // setup input (file)
+    QFileInfo FileInfo(vPrepareTrackChains[i].strFileName);
+    //      if ( vPrepareTrackChains[i].strFileName != "" ) {
+    if ( FileInfo.exists() ) {
+      nResult = CVoxStormGlobal::findStringFromList(
+                              vPrepareTrackChains[i].strFileName,
+                              strlInputFiles);
+      if ( nResult == -1 ) {
+        strlInputFiles.append(vPrepareTrackChains[i].strFileName);
+        command("ai-add " + DQ + vPrepareTrackChains[i].strFileName + DQ);
+      }
+
+      // setup output (device)
+      nResult = CVoxStormGlobal::findStringFromList(
+                              vPrepareTrackChains[i].strOutputDevice,
+                              strlOutputDevices);
+      if ( nResult == -1 ) {
+        strlOutputDevices.append(vPrepareTrackChains[i].strOutputDevice);
+        command("ao-add " + vPrepareTrackChains[i].strOutputDevice);
+      }
+    }
+  }
+
+  // set mixdown file name
+  command("ao-add " + DQ + strFileName + DQ);
+
+  QString  strSelection;
+  QStringList::Iterator itIO;
+  QValueVector<CTrackInf>::Iterator itTrack = vPrepareTrackChains.begin();
+
+  // >>>> attach inputs
+  // attach intput files
+  itIO = strlInputFiles.begin();
+  while ( itIO != strlInputFiles.end() ){
+    command("ai-select " + CVoxStormGlobal::fenceString(*itIO));
+
+    strSelection = "";
+    itTrack = vPrepareTrackChains.begin();
+    while ( itTrack != vPrepareTrackChains.end() ) {
+      if ( (*itIO) == (*itTrack).strFileName ) {
+        strSelection += (*itTrack).strTrackName + ",";
+      }
+      itTrack++;
+    }
+
+    slotSelectChain(strSelection.left(strSelection.length() - 1));
+    command("ai-attach");
+    itIO++;
+  }
+  // <<<< attach intputs
+
+  // >>>> attach oututs
+  // attach output devices
+  itIO = strlOutputDevices.begin();
+  while ( itIO != strlOutputDevices.end() ){
+    command("ao-select " + CVoxStormGlobal::fenceString(*itIO));
+
+    strSelection = "";
+    itTrack = vPrepareTrackChains.begin();
+    while ( itTrack != vPrepareTrackChains.end() ) {
+      if ( (*itIO) == (*itTrack).strOutputDevice ) {
+        strSelection += (*itTrack).strTrackName + ",";
+      }
+      itTrack++;
+    }
+
+    slotSelectChain(strSelection.left(strSelection.length() - 1));
+    command("ao-attach");
+    itIO++;
+  }
+
+  // attach output files
+  command("ao-select " + CVoxStormGlobal::fenceString(strFileName));
+
+  strSelection = "";
+  itTrack = vPrepareTrackChains.begin();
+  while ( itTrack != vPrepareTrackChains.end() ) {
+    strSelection += (*itTrack).strTrackName + ",";
+    itTrack++;
+  }
+
+  slotSelectChain(strSelection.left(strSelection.length() - 1));
+  command("ao-attach");
+  // <<<< attach outputs
+
+  destroyPreparings();
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 Status
 CEcaIAManager::engineStatus()
 {
@@ -819,9 +1002,7 @@ CEcaIAManager::timerEvent(QTimerEvent* TimerEvent)
   if ( TimerEvent->timerId() == nTimerIDFinished ) {
     if ( engineStatus() == Finished ) {
       killTimer(nTimerIDFinished);
-      removeTmpFiles();
-      bPlaying = false;
-      emit finished();
+      doDetailStopped();
     }
   }
   QObject::timerEvent(TimerEvent);
@@ -891,8 +1072,23 @@ CEcaIAManager::removeTmpFiles()
 
 /////////////////////////////////////////////////////////////////////////////
 
+void 
+CEcaIAManager::doDetailStopped()
+{
+  if ( rStatus == Mixing ) {
+    command("cs-remove");
+    command("cs-index-select 1");
+  }
+
+  rStatus = NotRunning;
+  removeTmpFiles();
+  emit finished();
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 void
-CEcaIAManager::prepareTracks()
+CEcaIAManager::prepareTracks(bool bIgnoresRecord)
 {
   vPrepareTrackChains.clear();
 
@@ -901,16 +1097,20 @@ CEcaIAManager::prepareTracks()
 
   for ( i = 0; i < nTracks; i++ ) {
     QFileInfo FileInfo(vTrackChains[i].strFileName);
-    bool bTest;
-    bTest = vTrackChains[i].bRecPort;
-    bTest = FileInfo.exists();
-    if ( (!vTrackChains[i].bRecPort && !FileInfo.exists()) ||
+    bool bEnabledRec;
+    if ( bIgnoresRecord ) {
+      bEnabledRec = false;
+    } else {
+      bEnabledRec = vTrackChains[i].bRecPort;
+    }
+
+    if ( (!bEnabledRec && !FileInfo.exists()) ||
          !CVoxStormGlobal::isSupportedFileType(vTrackChains[i].strFileName) ) {
       continue;
     }
 
     CEwf Ewf(vTrackChains[i]);
-    if ( Ewf.hasAdvantage() && !vTrackChains[i].bRecPort ) {
+    if ( Ewf.hasAdvantage() && !bEnabledRec ) {
       KTempFile TempFile(QString::null, ".ewf");
       CTrackInf TrackEwf = vTrackChains[i];
 
