@@ -38,14 +38,21 @@ class CEcaIAManager : public QObject
 {
   Q_OBJECT
 public:
+  enum RunningStatus {
+    NotRunning,
+    Playing,
+    Recording,
+    Mixing
+  };
+
   //! \brief 󥹥ȥ饯
   CEcaIAManager();
   //! \brief ǥȥ饯
   ~CEcaIAManager();
 
-  //! \brief  椫ɤ֤
-  //! \return ξ硢true֤ʳfalse֤
-  bool isPlaying();
+  //! \brief  Ծ֤֤
+  //! \return Ծ֡
+  RunningStatus runningStatus() const;
   //! \brief  ꤵ줿ȥå̾Τ˥󥻥åȥåפ¸ߤ뤫ɤ֤
   //! \param  strTrackName ȥå̾Ρ
   //! \return ¸ߤƤ硢true֤
@@ -86,6 +93,13 @@ public slots:
   //! \brief ÿ󥻥åȥåפꤹ롣
   //! \param nSecond ꤷÿ
   void slotForward(int nSecond);
+  //! \brief ߥå
+  //! \param bWithPlaying ʤߥå󤹤trueꡣ
+  //! \param strChainsetup ߥåѥ󥻥åȥå̾Ρ
+  //! \param strFileName ߥåե̾Ρ
+  void slotMixdown(bool bWithPlaying, 
+                   const QString& strChainsetup, 
+                   const QString& strFileName);
 
   //! \brief ȥåȤɲä롣
   //! \param TrackInfAdd Ȥɲäȥå
@@ -144,8 +158,8 @@ private:
   int nMasterPosition;
   //! ե̾Υꥹȡ
   QStringList strlTmpFiles;
-  //! ɽե饰
-  bool bPlaying;
+  //! Ծ
+  RunningStatus rStatus;
 
   //! ֥륯
   static const QString DQ;
@@ -176,6 +190,10 @@ private:
   //! \todo  too heavy
   //! ʣΥɥǥХбɬפ롣
   void setIOToCurrentChainsetup(bool bRecord);
+  //! \brief ߥåѤEcaControlerꤹ롣
+  //! \param bWithPlaying ʤߥå󤹤trueꡣ
+  //! \param strFileName ߥåե̾Ρ
+  void setMixdownIOToCurrentChainsetup(bool bWithPlaying, const QString& strFileName);
   //! \brief ߤξ֤֤
   Status engineStatus();
   //! \brief ޥ٥ȡ
@@ -193,12 +211,14 @@ private:
   //! ȥåνԤ줿ȥåvPrepareTrackChains
   //! ˳Ǽ롣
   //! setIOToCurrentChainsetupΤ߸ƤӽФġ
+  //! \param bIgnoresRecord ƥȥåΥ쥳ǥ󥰥ե饰̵뤹롣
+  //! ߥåϡtrueꤹ롣
   //! \todo ߤϡΥȥåvPrepareTrackChains˳ǼƤ롣
   //! setIOToCurrentChainsetupvPrepareTrackChains
   //! Ȥ褦ˤ̵̤ʤʤ롣
   //! 硢vPrepareTrackChainsˤϡΤǤϤʤ
   //! EwfѤΥȥåǼФ褤
-  void prepareTracks();
+  void prepareTracks(bool bIgnoresRecord=false);
   //! \brief ȥå˹Ԥä.ewfեν򸵤᤹
   //! setIOToCurrentChainsetupΤ߸ƤӽФġ
   //! \todo setIOToCurrentChainsetupvPrepareTrackChains
@@ -206,6 +226,8 @@ private:
   void destroyPreparings();
   //! \brief ƥݥե롣
   void removeTmpFiles();
+  //! \brief ߤ
+  void doDetailStopped();
 
 private slots:
   //! \brief 
