@@ -70,25 +70,28 @@ WVoxBase::~WVoxBase()
 void
 WVoxBase::addTrack(const QString& strDeviceIn, const QString& strDeviceOut)
 {
-  WNameDialog *NameDialog = new WNameDialog(this);
+  WNameDialog nameDialog(this);
 
-  NameDialog->setValidChars(CVoxStormGlobal::ValidCharsTrack);
+  nameDialog.setValidChars(CVoxStormGlobal::ValidCharsTrack);
 
-  if ( NameDialog->exec() == QDialog::Accepted ) {
-    QString strTrackName = NameDialog->getNameFromDialog();
+  if ( nameDialog.exec() == QDialog::Accepted ) {
+    QString strTrackName = nameDialog.getNameFromDialog();
     
     if ( queryExistingTrackName(strTrackName)) { // already exsists
-      QString strMessage = "The name \"";
-      strMessage += strTrackName;
-      strMessage += "\" is already existing.\nFailed in adding track.";
+      QString strMessage = i18n("Track name : ");
+      strMessage = "\"" + strTrackName + "\"\n";
+      strMessage += i18n("The track name is already existing.\n"
+                         "Failed in adding track.");
       KMessageBox::sorry(this, strMessage);
 
+    } else if ( strTrackName == "all" ) {
+      QString strMessage = 
+                i18n("The name \"all\" cannot be used for "
+                     "track name.\nFailed in adding track.");
     } else {
       addTrack(strTrackName, strDeviceIn, strDeviceOut);
     }
   }
-  
-  delete NameDialog;
 }
 
 /////////////////////////////////////////////////////////////////////////////
