@@ -31,6 +31,7 @@
 #include <kfiledialog.h>
 #include <qpopupmenu.h>
 #include "wvoxstorm.h"
+#include "wmixdowndialog.h"
 #include "cvoxstormglobal.h"
 
 /////////////////////////////////////////////////////////////////////////////
@@ -238,12 +239,16 @@ WVoxStorm::setupActions()
   Action->plug(PopupMenu);
   Action->plug(toolBar());
 
+  PopupMenu->insertSeparator();
+
   Action = KStdAction::save(this, SLOT(slotSave()), actionCollection());
   Action->plug(PopupMenu);
   Action->plug(toolBar());
 
   Action = KStdAction::saveAs(this, SLOT(slotSaveAs()), actionCollection());
   Action->plug(PopupMenu);
+
+  PopupMenu->insertSeparator();
       
   Action = KStdAction::quit(this, SLOT(close()), actionCollection());
   Action->plug(PopupMenu);
@@ -253,15 +258,16 @@ WVoxStorm::setupActions()
 
   PopupMenu = new QPopupMenu;
 
-  Action = new KAction(i18n("&Play"),
+  ActionPlay = new KAction(
+                       i18n("&Play"),
                        "voxstorm_play",
                        KShortcut(CTRL+Key_P),
                        this,
                        SLOT(slotPlay()),
                        actionCollection(),
                        "Play");
-  Action->plug(PopupMenu);
-  Action->plug(toolBar());
+  ActionPlay->plug(PopupMenu);
+  ActionPlay->plug(toolBar());
 
   ToggleActionRec = new KToggleAction(
                        i18n("&Record"),
@@ -294,35 +300,52 @@ WVoxStorm::setupActions()
   Action->plug(PopupMenu);
   Action->plug(toolBar());
 
-  Action = new KAction(i18n("&Jump to Start"),
+  PopupMenu->insertSeparator();
+
+  ActionJumpToStart = new KAction(i18n(
+                       "&Jump to Start"),
                        "voxstorm_start",
                        0,
                        this,
                        SLOT(slotJumpToStart()),
                        actionCollection(),
                        "Jump To Start");
-  Action->plug(PopupMenu);
-  Action->plug(toolBar());
+  ActionJumpToStart->plug(PopupMenu);
+  ActionJumpToStart->plug(toolBar());
 
-  Action = new KAction(i18n("Re&wind"),
+  ActionRewind = new KAction(
+                       i18n("Re&wind"),
                        "voxstorm_rewind",
                        0,
                        this,
                        SLOT(slotRewind()),
                        actionCollection(),
                        "Rewind");
-  Action->plug(PopupMenu);
-  Action->plug(toolBar());
+  ActionRewind->plug(PopupMenu);
+  ActionRewind->plug(toolBar());
 
-  Action = new KAction(i18n("&Forward"),
+  ActionForward = new KAction(
+                       i18n("&Forward"),
                        "voxstorm_forward",
                        0,
                        this,
                        SLOT(slotForward()),
                        actionCollection(),
                        "Forward");
-  Action->plug(PopupMenu);
-  Action->plug(toolBar());
+  ActionForward->plug(PopupMenu);
+  ActionForward->plug(toolBar());
+
+  PopupMenu->insertSeparator();
+
+  ActionMixdown = new KAction(
+                       i18n("&Mixdown..."), 
+                       "voxstorm_mixdown", 
+                       0, 
+                       this, 
+                       SLOT(slotMixdown()), 
+                       actionCollection(), 
+                       "Mixdown");
+  ActionMixdown->plug(PopupMenu);
 
   menuBar()->insertItem(i18n("&Operation"), PopupMenu);
 
@@ -350,7 +373,7 @@ WVoxStorm::setupActions()
 
   PopupMenu = new QPopupMenu;
 
-  //  toolBar()->insertLineSeparator();
+  toolBar()->insertLineSeparator();
 
   ToggleActionInteractive = new KToggleAction(
                        i18n("&Interactive Mode"),
@@ -470,24 +493,13 @@ WVoxStorm::isChanged() const
 
 /////////////////////////////////////////////////////////////////////////////
 
-bool
-WVoxStorm::isPlaying()
-{
-  return EcaIAManager.isPlaying();
-}
-
-/////////////////////////////////////////////////////////////////////////////
-
 QString
 WVoxStorm::createNewUntitledName() const
 {
   static unsigned int unID;
-  QString strNewUntitledName;
 
   unID++;
-  strNewUntitledName.sprintf("%s%d", "Untitled", unID);
-
-  return strNewUntitledName;
+  return QString("%1%2").arg(i18n("Untitled")).arg(unID);
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -496,7 +508,7 @@ void
 WVoxStorm::loadFile(const QString& strFileName)
 {
   QApplication::setOverrideCursor(waitCursor);
-  LabelStatusBar->setText("Loading...");
+  LabelStatusBar->setText(i18n("Loading..."));
 
   QDomDocument doc;
   QFile File(strFileName);
@@ -579,8 +591,7 @@ void
 WVoxStorm::enterIAMode(bool bEnter)
 {
   if ( bEnter ) {
-    QString strChainsetup = sessionName();
-    EcaIAManager.slotCreateNewChainsetup(strChainsetup);
+    EcaIAManager.slotCreateNewChainsetup("VoxStorm");
   } else {
     // clear chainsetup
     EcaIAManager.slotReleaseCurrentChainsetup();
@@ -650,9 +661,9 @@ WVoxStorm::slotOpen()
   if ( maybeSave() ) {
     KURL url = KFileDialog::getOpenURL(
                  QString::null, 
-                 "*.voxs|VoxStorm session files (.voxs)\n*|All files", 
+                 i18n("*.voxs|VoxStorm session files (*.voxs)\n*|All files (*)"), 
                  NULL, 
-                 "Open VoxStorm session file");
+                 i18n("Open VoxStorm session file"));
     if ( !url.isEmpty() ) {
       if ( url.isLocalFile() ) {
 	loadFile(url.path());	
@@ -682,13 +693,13 @@ WVoxStorm::slotSave()
 bool 
 WVoxStorm::slotSaveAs()
 {
-  KFileDialog Dialog(QString::null,
-                     "*.voxs|VoxStorm session files (.voxs)", 
+  KFileDialog dialog(QString::null,
+                     i18n("*.voxs|VoxStorm session files (*.voxs)"), 
                      NULL,
-                     "Save VoxStorm session file", 
+                     i18n("Save VoxStorm session file"), 
                      true);
-  Dialog.exec();
-  QString strFileName = Dialog.selectedFile();
+  dialog.exec();
+  QString strFileName = dialog.selectedFile();
   if ( strFileName == "" ) {
     return false;
   }
@@ -702,8 +713,8 @@ WVoxStorm::slotSaveAs()
   if ( FileInfo.exists() ) {
     if ( KMessageBox::warningYesNo(
            this, 
-           QString("A file named \"%1\" already exists. "
-                "Are you sure you want to overwrite it?").arg(FileInfo.filePath()), 
+           QString(i18n("A file named \"%1\" already exists. "
+                "Are you sure you want to overwrite it?").arg(FileInfo.filePath())), 
            "Overwrite File?") != KMessageBox::Yes ) {
       return false;
     }
@@ -723,9 +734,9 @@ WVoxStorm::slotPlay()
 {
   QApplication::setOverrideCursor(waitCursor);
   if ( ToggleActionRec->isChecked() ) {
-    LabelStatusBar->setText("Recording...");
+    LabelStatusBar->setText(i18n("Recording..."));
   } else {
-    LabelStatusBar->setText("Playing...");
+    LabelStatusBar->setText(i18n("Playing..."));
   }
   if ( ToggleActionInteractive->isChecked() ) {
     EcaIAManager.slotRemoveAllChains();
@@ -735,10 +746,12 @@ WVoxStorm::slotPlay()
       EcaIAManager.slotAddChain(VoxBase->getTrackInf(i));
     }
 
-    EcaIAManager.slotPlay(ToggleActionRec->isChecked());
+    ActionPlay->setEnabled(false);
     ToggleActionRec->setEnabled(false);
+    ActionMixdown->setEnabled(false);
     VoxBase->slotSetEnabledWidgets(WVoxBase::Play);
     VoxBase->slotChangeMessageTab(WVoxBase::Console);
+    EcaIAManager.slotPlay(ToggleActionRec->isChecked());
   } else {
   }
   QApplication::restoreOverrideCursor();
@@ -815,17 +828,60 @@ WVoxStorm::slotForward()
 
 /////////////////////////////////////////////////////////////////////////////
 
+void 
+WVoxStorm::slotMixdown()
+{
+  if ( ToggleActionRec->isChecked() ) {
+    KMessageBox::warningYesNo(
+      this, 
+      i18n("Recording action is enabled now.\n"
+           "Please be disabled Recording action to mixdown."));
+    return;
+  }
+
+  WMixdownDialog mixdownDialog(this);
+
+  if ( mixdownDialog.exec() != QDialog::Accepted ) {
+    return;
+  }
+
+  QApplication::setOverrideCursor(waitCursor);
+
+  LabelStatusBar->setText(i18n("Mixing..."));
+
+  EcaIAManager.slotRemoveAllChains();
+  int nCount = VoxBase->getTrackCount();
+  int i;
+  for ( i = 0; i < nCount; i++ ) {
+    EcaIAManager.slotAddChain(VoxBase->getTrackInf(i));
+  }
+
+  ActionPlay->setEnabled(false);
+  ToggleActionRec->setEnabled(false);
+  ActionJumpToStart->setEnabled(false);
+  ActionRewind->setEnabled(false);
+  ActionForward->setEnabled(false);
+  ActionMixdown->setEnabled(false);
+  VoxBase->slotSetEnabledWidgets(WVoxBase::Play);
+  VoxBase->slotChangeMessageTab(WVoxBase::Console);
+  EcaIAManager.slotMixdown(
+        mixdownDialog.mixesWithPlaying(), 
+        "Mixdown", 
+        mixdownDialog.fileName());
+  QApplication::restoreOverrideCursor();
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 void
 WVoxStorm::slotPreferences()
 {
-  WPrefDialog *PrefDialog = new WPrefDialog(this);
-  PrefDialog->setFields(Preferences);
-  if ( PrefDialog->exec() == QDialog::Accepted ) {
-    Preferences = PrefDialog->fields();
+  WPrefDialog prefDialog(this);
+  prefDialog.setFields(Preferences);
+  if ( prefDialog.exec() == QDialog::Accepted ) {
+    Preferences = prefDialog.fields();
   }
 
-  delete PrefDialog;
-
   writeConfigurationFile();
 }
 
@@ -1028,7 +1084,12 @@ WVoxStorm::slotFinish()
     VoxBase->slotNotifySucceedInRecording();
   }
   VoxBase->slotSetEnabledWidgets(WVoxBase::Stop);
+  ActionMixdown->setEnabled(true);
+  ActionForward->setEnabled(true);
+  ActionRewind->setEnabled(true);
+  ActionJumpToStart->setEnabled(true);
   ToggleActionRec->setEnabled(true);
+  ActionPlay->setEnabled(true);
   LabelStatusBar->setText("");
 }
 
