@@ -85,8 +85,18 @@ private:
   int          nMenuIDRec;
   //! ϿġܥID
   int          nToolIDRec;
+  //! 
+  KAction*       ActionPlay;
+  //! 
+  KAction*       ActionJumpToStart;
+  //! ᤷ
+  KAction*       ActionRewind;
+  //! ꥢ
+  KAction*       ActionForward;
   //! Ͽ
   KToggleAction* ToggleActionRec;
+  //! ߥå󥢥
+  KAction*       ActionMixdown;
   //! 󥿥饯ƥ֥⡼ɥ
   KToggleAction* ToggleActionInteractive;
   //! ƥե饰
@@ -101,8 +111,6 @@ private:
 
   //! \brief ѹ뤫ɤȽǤ롣
   bool isChanged() const;
-  //! \brief 椫ɤȽǤ롣
-  bool isPlaying();
   //! \brief ¸Ԥ桼˿Ҥͤ롣
   bool maybeSave();
   //! \brief ֿ׻˥ǥեȤΥե̾Τư롣
@@ -118,6 +126,9 @@ private:
   void saveFile(const QString& strFileName);
   //! \brief ߤΥåե򥢥ץꥱꤹ롣
   void setCurrentFile(const QString& strFileName);
+  //! \brief ꤵ줿ե˥ߥå󤹤롣
+  //! \param strFileName ¸ե̾Ρ
+  void mixdown(const QString& strFileName);
   //! \brief 󥿥饯ƥ֥⡼ɤؽꤹ롣
   //! \param bEnter Ȥϡtrueꡣ
   void enterIAMode(bool bEnter);
@@ -151,6 +162,8 @@ private slots:
   void slotRewind();
   //! \brief פꤵ줿Υåȡ
   void slotForward();
+  //! \brief ֥ߥåפꤵ줿Υåȡ
+  void slotMixdown();
   //! \brief פꤵ줿Υåȡ
   void slotPreferences();
   //! \brief ֥󥿥饯ƥ֥⡼ɡפꤵ줿Υåȡ
