@@ -117,9 +117,9 @@ WVoxTrack::setupWidgets()
   HBoxButtonBase = new QHBox(VBoxController);
 
   // HBoxButtonBase has FileChooserTrack, WidgetSpacer, ColorButtonMute, ColorButtonRec
-  FileChooserTrack = new WFileChooser("", "Detect sound source file", HBoxButtonBase);
-  FileChooserTrack->setFileType("*.wav *.mp3|Sound files (*.wav; *.mp3)\n*"
-                                "|All files (*)");
+  FileChooserTrack = new WFileChooser("", i18n("Detect sound source file"), HBoxButtonBase);
+  FileChooserTrack->setFileType(i18n("*.wav *.mp3|Sound files (*.wav; *.mp3)\n*"
+                                "|All files (*)"));
 
   WidgetSpacer = new QHBox(HBoxButtonBase);
   WidgetSpacer->setMinimumWidth(10);
@@ -658,10 +658,10 @@ WVoxTrack::slotSetEnabledWidgets(unsigned int unWidgets, bool bEnabled)
 void 
 WVoxTrack::slotChangePlaybackDevice()
 {
-  KLineEditDlg LineEditDlg("Playback device of this track",
+  KLineEditDlg lineEditDlg("Playback device of this track",
                            strOutputDevice, this);
-  if ( LineEditDlg.exec() == QDialog::Accepted ) {
-    strOutputDevice = LineEditDlg.text();
+  if ( lineEditDlg.exec() == QDialog::Accepted ) {
+    strOutputDevice = lineEditDlg.text();
     emit playbackDeviceChanged(strOutputDevice);
   }
 }
@@ -671,10 +671,10 @@ WVoxTrack::slotChangePlaybackDevice()
 void 
 WVoxTrack::slotChangeRecordingDevice()
 {
-  KLineEditDlg LineEditDlg("Recording device of this track",
+  KLineEditDlg lineEditDlg("Recording device of this track",
                            strInputDevice, this);
-  if ( LineEditDlg.exec() == QDialog::Accepted ) {
-    strInputDevice = LineEditDlg.text();
+  if ( lineEditDlg.exec() == QDialog::Accepted ) {
+    strInputDevice = lineEditDlg.text();
     emit recordingDeviceChanged(strInputDevice);
   }
 }
@@ -703,15 +703,15 @@ WVoxTrack::slotRename()
 void
 WVoxTrack::slotChangeStartPosition()
 {
-  WTimeDialog TimeDialog(this);
+  WTimeDialog timeDialog(this);
 
-  TimeDialog.setCaption("Set Start Position");
-  TimeDialog.setTime(TimeStartPosition);
-  TimeDialog.setDisplay(
+  timeDialog.setCaption("Set Start Position");
+  timeDialog.setTime(TimeStartPosition);
+  timeDialog.setDisplay(
       WTimeDialog::Minutes | WTimeDialog::Seconds | WTimeDialog::MilliSecs);
 
-  if ( TimeDialog.exec() == QDialog::Accepted ) {
-    TimeStartPosition = TimeDialog.time();
+  if ( timeDialog.exec() == QDialog::Accepted ) {
+    TimeStartPosition = timeDialog.time();
     emit startPositionChanged(TimeStartPosition);
   }
 }
@@ -721,15 +721,15 @@ WVoxTrack::slotChangeStartPosition()
 void
 WVoxTrack::slotChangeOffset()
 {
-  WTimeDialog TimeDialog(this);
+  WTimeDialog timeDialog(this);
 
-  TimeDialog.setCaption("Set Offset from Origin");
-  TimeDialog.setTime(TimeOffset);
-  TimeDialog.setDisplay(
+  timeDialog.setCaption("Set Offset from Origin");
+  timeDialog.setTime(TimeOffset);
+  timeDialog.setDisplay(
       WTimeDialog::Minutes | WTimeDialog::Seconds | WTimeDialog::MilliSecs);
 
-  if ( TimeDialog.exec() == QDialog::Accepted ) {
-    TimeOffset = TimeDialog.time();
+  if ( timeDialog.exec() == QDialog::Accepted ) {
+    TimeOffset = timeDialog.time();
     emit offsetChanged(TimeOffset);
   }
 }
@@ -739,15 +739,15 @@ WVoxTrack::slotChangeOffset()
 void
 WVoxTrack::slotChangeLength()
 {
-  WTimeDialog TimeDialog(this);
+  WTimeDialog timeDialog(this);
 
-  TimeDialog.setCaption("Set Length for Playing Time");
-  TimeDialog.setTime(TimeLength);
-  TimeDialog.setDisplay(
+  timeDialog.setCaption("Set Length for Playing Time");
+  timeDialog.setTime(TimeLength);
+  timeDialog.setDisplay(
       WTimeDialog::Minutes | WTimeDialog::Seconds | WTimeDialog::MilliSecs);
 
-  if ( TimeDialog.exec() == QDialog::Accepted ) {
-    TimeLength = TimeDialog.time();
+  if ( timeDialog.exec() == QDialog::Accepted ) {
+    TimeLength = timeDialog.time();
     emit lengthChanged(TimeLength);
   }
 }
